@@ -1,6 +1,6 @@
 # @file EmpiricalCalibrationUsingMcmc.R
 #
-# Copyright 2022 Observational Health Data Sciences and Informatics
+# Copyright 2025 Observational Health Data Sciences and Informatics
 #
 # This file is part of EmpiricalCalibration
 #
@@ -177,11 +177,16 @@ fitMcmcNull <- function(logRr, seLogRr, iter = 100000) {
     seLogRr <- seLogRr[!is.na(logRr)]
     logRr <- logRr[!is.na(logRr)]
   }
+  if (any(abs(logRr) > log(100))) {
+    warning("Estimate(s) with extreme logRr detected: abs(logRr) > log(100). Removing before fitting null distribution")
+    seLogRr <- seLogRr[abs(logRr) <= log(100)]
+    logRr <- logRr[abs(logRr) <= log(100)]
+  }
   if (length(logRr) == 0) {
     warning("No valid estimates left. Returning undefined null distribution")
     mcmc <- list(chain = matrix(c(NA,NA), nrow = 1, ncol = 2))
   } else {
-    fit <- optim(c(0, 100), logLikelihoodNullMcmc, logRr = logRr, seLogRr = seLogRr)
+    fit <- optim(c(0, 1), logLikelihoodNullMcmc, logRr = logRr, seLogRr = seLogRr)
     
     # Profile likelihood for roughly correct scale:
     scale <- binarySearchMu(fit$par[1],
